import { __decorate, __metadata, __param } from "tslib";
import * as Path from 'path';
import { DEFAULT_MAGICSPACE_DIRNAME, buildConfigSchema, resolveBoilerplateModule, } from '@magicspace/core';
import Chalk from 'chalk';
import { Command, ExpectedError, Options, command, metadata, option, param, } from 'clime';
import FSExtra from 'fs-extra';
import prompts from 'prompts';
import { CONFIG_SCHEMA_FILE_NAME } from '../@constants.js';
export class CreateOptions extends Options {
    constructor() {
        super(...arguments);
        Object.defineProperty(this, "schema", {
            enumerable: true,
            configurable: true,
            writable: true,
            value: void 0
        });
    }
}
__decorate([
    option({
        toggle: true,
        description: 'Generate JSON schema for boilerplate.json',
        default: false,
    }),
    __metadata("design:type", Boolean)
], CreateOptions.prototype, "schema", void 0);
let default_1 = class extends Command {
    async execute(boilerplate, { schema: toGenerateJSONSchema }) {
        var _a;
        const magicspaceDir = Path.resolve(DEFAULT_MAGICSPACE_DIRNAME);
        if (FSExtra.existsSync(magicspaceDir)) {
            throw new ExpectedError(`Folder ${JSON.stringify(DEFAULT_MAGICSPACE_DIRNAME)} already exists`);
        }
        const { examples, Options } = await resolveBoilerplateModule(boilerplate, process.cwd());
        let example;
        if (examples && examples.length > 1) {
            example = (await prompts({
                type: 'select',
                name: 'example',
                message: 'Select a boilerplate example configuration',
                instructions: false,
                choices: examples.map(example => {
                    var _a;
                    return {
                        title: (_a = example.name) !== null && _a !== void 0 ? _a : 'default',
                        description: example.description,
                        value: example,
                    };
                }),
            })).example;
            if (!example) {
                return;
            }
        }
        else {
            example = examples === null || examples === void 0 ? void 0 : examples[0];
        }
        const configFilePath = Path.join(magicspaceDir, 'boilerplate.json');
        const extendsSpecifier = /^[.]{1,2}[\\/]/.test(boilerplate)
            ? Path.relative(magicspaceDir, Path.resolve(boilerplate)).replace(/\\/g, '/')
            : boilerplate;
        await FSExtra.outputFile(configFilePath, `${JSON.stringify({
            ...(toGenerateJSONSchema
                ? { $schema: CONFIG_SCHEMA_FILE_NAME }
                : undefined),
            boilerplate: extendsSpecifier,
            options: (_a = example === null || example === void 0 ? void 0 : example.options) !== null && _a !== void 0 ? _a : {},
        }, undefined, 2)}\n`);
        if (toGenerateJSONSchema && Options) {
            const configSchemaPath = Path.join(magicspaceDir, CONFIG_SCHEMA_FILE_NAME);
            await FSExtra.outputFile(configSchemaPath, JSON.stringify(buildConfigSchema(Options), undefined, 2));
        }
        return `\
Created magicspace configuration at ${JSON.stringify(Path.relative('.', configFilePath))}.
Please review/edit the configuration file and run ${Chalk.yellow('magicspace init')} to initialize.`;
    }
};
__decorate([
    metadata,
    __param(0, param({
        description: 'Boilerplate specifier',
        required: true,
    })),
    __metadata("design:type", Function),
    __metadata("design:paramtypes", [String, CreateOptions]),
    __metadata("design:returntype", Promise)
], default_1.prototype, "execute", null);
default_1 = __decorate([
    command({
        description: 'Create magicspace config file',
    })
], default_1);
export default default_1;
//# sourceMappingURL=create.js.map