import { __decorate, __metadata, __param } from "tslib";
import * as Path from 'path';
import Chalk from 'chalk';
import { Command, ExpectedError, command, metadata, option, param } from 'clime';
import { CommonOptions } from '../@command.js';
import { createDefaultSpace } from '../@space.js';
export class InitOptions extends CommonOptions {
    constructor() {
        super(...arguments);
        Object.defineProperty(this, "ours", {
            enumerable: true,
            configurable: true,
            writable: true,
            value: void 0
        });
    }
}
__decorate([
    option({
        toggle: true,
        description: 'Use "ours" merge strategy',
        default: false,
    }),
    __metadata("design:type", Boolean)
], InitOptions.prototype, "ours", void 0);
let default_1 = class extends Command {
    async execute(projectDir, options) {
        const space = await createDefaultSpace(Path.resolve(projectDir), Path.resolve(projectDir, options.magicspace));
        if (space === 'magicspace-dir-not-exists') {
            throw new ExpectedError('Magicspace configuration not found');
        }
        const result = await space.initialize(options);
        switch (result) {
            case true:
                return `\
Magicspace initialization started, please review and commit changes to complete the initialize merge.

Please avoid resetting the on-going merge if you want to continue and complete this initialization.
Otherwise, you can use ${Chalk.yellow('git merge --abort')} to cancel this initialization and start over again.`;
            case 'not-repository-root':
                throw new ExpectedError(`Project directory ${JSON.stringify(projectDir)} is not repository root`);
            case 'merge-in-progress':
                throw new ExpectedError('A merge is already in progress, please resolve it before continue');
            case 'already-initialized':
                throw new ExpectedError(`This repository has already been initialized with magicspace, run ${Chalk.yellow('magicspace update')} instead`);
        }
    }
};
__decorate([
    metadata,
    __param(0, param({
        default: '.',
    })),
    __metadata("design:type", Function),
    __metadata("design:paramtypes", [String, InitOptions]),
    __metadata("design:returntype", Promise)
], default_1.prototype, "execute", null);
default_1 = __decorate([
    command({
        description: 'Initialize magicspace',
    })
], default_1);
export default default_1;
//# sourceMappingURL=init.js.map