import { __decorate, __metadata, __param } from "tslib";
import * as Path from 'path';
import { Command, ExpectedError, command, metadata, param } from 'clime';
import prompts from 'prompts';
import { createDefaultSpace } from '../@space.js';
let default_1 = class extends Command {
    async execute(projectDir) {
        const space = await createDefaultSpace(Path.resolve(projectDir));
        if (!space.isRepositoryRoot()) {
            throw new ExpectedError(`Project directory ${JSON.stringify(projectDir)} is not repository root`);
        }
        if (!space.isMerging()) {
            throw new ExpectedError('This project is not actively merging');
        }
        const renames = space.listPendingPossibleDirectoryRenames();
        if (!renames.length) {
            return 'No pending possible directory renames detected.';
        }
        const selectedRenames = (await prompts([
            {
                type: 'multiselect',
                name: 'renames',
                message: 'Select directory renames to apply',
                instructions: false,
                choices: renames.map(rename => {
                    return {
                        title: `${rename.from} -> ${rename.to}`,
                        value: rename,
                    };
                }),
            },
        ])).renames;
        if (selectedRenames.length) {
            space.renameDirectories(selectedRenames);
            return 'Renaming completed.';
        }
        else {
            return 'Nothing selected.';
        }
    }
};
__decorate([
    metadata,
    __param(0, param({
        default: '.',
    })),
    __metadata("design:type", Function),
    __metadata("design:paramtypes", [String]),
    __metadata("design:returntype", Promise)
], default_1.prototype, "execute", null);
default_1 = __decorate([
    command({
        description: 'Update possible renamed directories interactively',
    })
], default_1);
export default default_1;
//# sourceMappingURL=update-dirs.js.map